.. complexity documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

multigtfs: GTFS as a Django app
===============================

.. include:: ../README.rst
    :start-after: .. Omit badges from docs

Contents:

.. toctree::
   :maxdepth: 2

   users
   installation
   usage
   gtfs
   contributors
   authors
   history
   future
   changelog
